This crate provides procedural macros for the microscpi library.
The main macro is interface, which processes an implementation block
to generate the code needed for an SCPI command interpreter.
Attribute Macros
- interface
- Macro attribute to define an SCPI interface.